/*
	GEDemoWindow.cpp
	
	Be Window class for Graphic Elements Demo
	
	Copyright 1996 by Al Evans. All rights reserved.
	
	2/17/96
	
*/

#include "GEDemoWindow.h"
#include "GEDemoView.h"
#include "GetTextDialog.h"

#define MSG_SHOOT_CANNON	'ShCn'
#define MSG_CHANGE_SIGN		'ChSn'
#define MSG_GRABBER			'AcGr'

GEDemoWindow::GEDemoWindow()
		: BWindow(BRect(50,50,100,100), "GE Demo", B_TITLED_WINDOW, B_NOT_RESIZABLE)
{
	Lock();
	mRefRect.Set(0, 0, 511, 363);
	ResizeTo(mRefRect.Width(), mRefRect.Height() + 15);
	SetupMenus();
	mView = NULL;
	Unlock();
}

GEDemoWindow::~GEDemoWindow()
{
	if (mView != NULL) {
		delete mView;
	}
}

void GEDemoWindow::MessageReceived(BMessage *message)
{
	static bool bloof = false;
	
	switch (message->what) {
		case MSG_SHOOT_CANNON:
			mView->ShootCannon();
			break;
		case MSG_CHANGE_SIGN:
			char oldText[256];
			mView->GetSignText(oldText);
			new GetTextDialog(this, "New text:", oldText);
			break;
		case MSG_GRABBER:
			mView->ActivateGrabber(!mView->GrabberActive());
			break;
		case MSG_NEW_TEXT:
			mView->SetSignText(message->FindString("text"));
			break;
		default:
			BWindow::MessageReceived(message);
			break;
	}
}

void GEDemoWindow::MenusWillShow()
{
	BMenuItem *grabberItem = mSMenu->FindItem(MSG_GRABBER);
	
	grabberItem->SetMarked(mView->GrabberActive());
	
}

void GEDemoWindow::SetupMenus()
{
	BRect mBounds = Bounds();
	
	mBounds.bottom = mBounds.top + 14;
	BMenuBar *menuBar = new BMenuBar(mBounds, "GE Demo");
	mSMenu = new BMenu("Special");
	menuBar->AddItem(mSMenu);
	BMenuItem *item = new BMenuItem("Shoot Cannon", new BMessage(MSG_SHOOT_CANNON), 'S' );
	item->SetTarget(this);
	mSMenu->AddItem(item);
	item = new BMenuItem("Change Sign Text", new BMessage(MSG_CHANGE_SIGN), 'T');
	item->SetTarget(this);
	mSMenu->AddItem(item);
	item = new BMenuItem("Activate Grabber", new BMessage(MSG_GRABBER), 'G');
	item->SetTarget(this);
	mSMenu->AddItem(item);
	AddChild(menuBar);
}

bool GEDemoWindow::LoadScene()
{
	bool ret;
	
	Lock();
	BRect viewRect = mRefRect;
	viewRect.OffsetBy(0, 15);
	mView = new GEDemoView(viewRect);
	if (mView == NULL)
		ret = false;
	else {
		AddChild(mView);
		ret = (mView->InitDemoWorld());
	}
	Unlock();
	return ret;
}

bool GEDemoWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return(TRUE);
}


