/*
	GetTextDialog.cpp
	
	Dialog class for getting a line of text.
	
	When the OK button is pressed, it sends a MSG_NEW_TEXT message to its parent
	window containing a string labelled 'text'.
	
	Based on -- OK, practically stolen from -- the "Find" dialog in John Norstad's 
	BetterEdit. Thanks, John!
	
	Al Evans
	
	2/21/96
	
*/

#include "GetTextDialog.h"

GetTextDialog::GetTextDialog(BWindow *parent, const char *title, const char *oldText)
				: BWindow(BRect(0, 0, 360, 100), "", B_MODAL_WINDOW, B_NOT_RESIZABLE)
{
	Lock();
	
	rgb_color lightGray = {208, 208, 208, 0};
	BRect bounds = Bounds();
	mParent = parent;
	
	// Center in parent window
	BRect pRect = parent->Frame();
	MoveTo(pRect.left + ((pRect.Width() - bounds.Width()) / 2),
			pRect.top + ((pRect.Height() - bounds.Height()) / 2));
			
	// Make the background light gray.
	BView *top = new BView(bounds, "", B_FOLLOW_NONE, B_WILL_DRAW);
	AddChild(top);
	top->SetViewColor(lightGray);
	
	// Text entry field
	BRect entryRect(10, 20, 70, 36);
	MakeTextEntryField(entryRect, title, top, "entry", true, oldText); 

	// OK button.
		
	BRect okButtonRect(bounds.right-90, bounds.bottom-35,
		bounds.right-20, bounds.bottom-10);
	BButton *okButton = new BButton(okButtonRect, "",
		"OK", new BMessage('okok'));
	top->AddChild(okButton);	
	SetDefaultButton(okButton);
	
	// Cancel button.
	
	BRect cancelButtonRect(okButtonRect.left - 100, okButtonRect.top, 
		okButtonRect.right - 100, okButtonRect.bottom);
	BButton *cancelButton = new BButton(cancelButtonRect, "cancel",
		"Cancel", new BMessage('cncl'));
	top->AddChild(cancelButton);
	
	Show();
	Unlock();
	
}


GetTextDialog::~GetTextDialog()
{
}

void GetTextDialog::MessageReceived(BMessage *msg)
{
	switch (msg->what) {	
		case 'okok':
			{
				BTextView *textView = (BTextView *) FindView("entry");
				BMessage *textMsg = new BMessage(MSG_NEW_TEXT);
				textMsg->AddString("text", textView->Text());
				mParent->PostMessage(textMsg);
				Quit();
			}	
		case 'cncl':
			Quit();
		default:
			BWindow::MessageReceived(msg);
			break;			
	}
}

void GetTextDialog::MakeTextEntryField(BRect labelRect, const char *label,
										BView *container, const char *name, bool makeFocus, 
										const char *initValue)
{
	BRect bounds = Bounds();

	BStringView *stringView = new BStringView(labelRect, "", label);
	stringView->SetAlignment(B_ALIGN_RIGHT);
	container->AddChild(stringView);
	stringView->SetLowColor(container->ViewColor());
	stringView->SetFontName("Emily");

	BRect frameRect(labelRect.right+6, labelRect.top, 
		bounds.right-20, labelRect.bottom);
	BBox *frame = new BBox(frameRect);
	container->AddChild(frame);
	
	BRect viewRect = frameRect;
	viewRect.OffsetTo(B_ORIGIN);
	viewRect.InsetBy(3,3);
	BRect textRect = viewRect;
	textRect.OffsetTo(B_ORIGIN);
	BTextView *textView = new BTextView(viewRect, name, textRect, 
		B_FOLLOW_NONE, B_WILL_DRAW);
	for (ulong c = 0; c < ' '; c++) {
		if (c != B_BACKSPACE && c != B_LEFT_ARROW && c != B_RIGHT_ARROW) 
			textView->DisallowChar(c);
	}
	frame->AddChild(textView);
	if (makeFocus) textView->MakeFocus();
	textView->SetFontName("Kate");
	textView->SetText(initValue);
	textView->Select(0, textView->TextLength());
}





