/*
	Sign.c
	
	User-entered text for Graphic Elements demo
	
	Copyright 1993 by Al Evans. All rights reserved.
	
	11/11/93
	
*/

#include "Sign.h"
#include "GEMEM.H"	

#if defined(TARGET_IS_MACOS)
Str255	signText = "\pMessage Here!";
#else
Str255	signText = "Message Here!";
#endif

typedef struct {
			Boolean signOn;
			RGBColor color[2];
} BlinkRec, *BlinkRecPtr;


PAS_FUNC(void, DisposeSign)(GEWorldPtr world, GrafElPtr element)
{
	if (element->changeData)
		DisposPtr(element->changeData);
#if defined(TARGET_IS_WIN95)
	DisposeFont(world, element);
#endif
}

Boolean LoadSignScene(GEWorldPtr world)
{
	GrafElPtr		thisElement;
	BlinkRecPtr		signBlink;

#if defined(TARGET_IS_MACOS)
	unsigned char	fontName[] = "\pChicago";
#endif

#if defined(TARGET_IS_WIN95)
	unsigned char	fontName[] = "Comic Sans MS";
#endif
	
#if defined(TARGET_IS_BEOS)
	unsigned char	fontName[] = "Arial MT Bold";
#endif

	
	signBlink = (BlinkRecPtr) NewPtrClear(sizeof(BlinkRec));
	
	signBlink->signOn = false;
	signBlink->color[0].red = 194 << 8;
	signBlink->color[0].green = 194 << 8;
	signBlink->color[0].blue = 0;
	signBlink->color[1].red = 240 << 8;
	signBlink->color[1].green = 240 << 8;
	signBlink->color[1].blue = 46 << 8;
	
	//Create sign
	thisElement = NewTextGraphic(world, signID, signPlane, signLeft, signTop, srcOr,
							fontName, bold, 18, signBlink->color[signBlink->signOn], signText);
	if (!thisElement) return false;
	
	//Initialize blinking action
	SetAutoChange(world, signID, DoSign, (Ptr) signBlink, 750);
	
	//Be sure to Dispose blink record
	SetCleanupProc(world, signID, DisposeSign);
	
	return true;
					
}

PAS_FUNC(void, DoSign)(GEWorldPtr world, GrafElPtr sign)
{
#pragma unused (world)
	BlinkRecPtr	blink;
	
	blink = (BlinkRecPtr) sign->changeData;
	
	blink->signOn = !blink->signOn;
	((TextGraphicPtr) sign)->tgColor = blink->color[blink->signOn];
	ChangedRect(world, &sign->animationRect);
}

PAS_FUNC(void, GetSignText)(StringPtr oldText)
{
#if defined(TARGET_IS_MACOS)
	BlockMove((Ptr) signText, (Ptr) oldText, (long) *signText + 1);
#else
	strcpy((char *) oldText, (char *) signText);
#endif
}

//Change sign text
PAS_FUNC(void, SetSignText)(GEWorldPtr world, StringPtr newText)
{
#if defined(TARGET_IS_MACOS)
	BlockMove((Ptr) newText, (Ptr) signText, (long) *newText + 1);
#else
	strcpy((char *) signText, (char *) newText);
#endif
	SetTextGraphicText(world, signID, signText);
}

